@@ -100,6 +100,7 @@ class System(item.Item):
         self.owners               = self.load_item(seed_data, 'owners', self.settings.default_ownership)
         self.profile              = self.load_item(seed_data, 'profile')
         self.image                = self.load_item(seed_data, 'image')
+
         self.kernel_options       = self.load_item(seed_data, 'kernel_options', {})
         self.kernel_options_post  = self.load_item(seed_data, 'kernel_options_post', {})
         self.ks_meta              = self.load_item(seed_data, 'ks_meta', {})
@@ -160,6 +161,12 @@ class System(item.Item):
         self.set_netboot_enabled(self.netboot_enabled)
         self.set_owners(self.owners) 
 
+
+        # enforce that the system extends from a profile or system but not both
+        # profile wins as it's the more common usage
+        self.set_image(self.image)
+        self.set_profile(self.profile)
+
         return self
 
     def get_parent(self):
@@ -302,13 +309,14 @@ class System(item.Item):
         Set the system to use a certain named profile.  The profile
         must have already been loaded into the Profiles collection.
         """
-        if profile_name in [ "delete", ""] or profile_name is None:
+        if profile_name in [ "delete", "None", "~", ""] or profile_name is None:
             self.profile = ""
             return True
+
+        self.image = "" # mutual exclusion rule
+
         p = self.config.profiles().find(name=profile_name)
         if p is not None:
-            if self.image is not None and self.image != "" and profile_name not in ["delete", ""]:
-                raise CX(_("image and profile settings are mutually exclusivei (%s,%s)") % (image.name,profile_name))
             self.profile = profile_name
             self.depth = p.depth + 1 # subprofiles have varying depths.
             return True
@@ -319,17 +327,19 @@ class System(item.Item):
         Set the system to use a certain named image.  Works like set_profile
         but cannot be used at the same time.  It's one or the other.
         """
-        if image_name in [ "delete", ""] or image_name is None:
+        if image_name in [ "delete", "None", "~", ""] or image_name is None:
             self.image = ""
             return True
+
+        self.profile = "" # mutual exclusion rule
+
         img = self.config.images().find(name=image_name)
+
         if img is not None:
-            if self.profile is not None and self.profile != "" and image_name not in ["delete", ""]:
-                raise CX(_("image and profile settings are mutually exclusive (%s,%s)") % (image_name,self.profile))
             self.image = image_name
             self.depth = img.depth + 1
             return True
-        raise CX(_("invalid image name"))
+        raise CX(_("invalid image name (%s)") % image_name)
 
     def set_virt_cpus(self,num):
         return utils.set_virt_cpus(self,num)
@@ -375,10 +385,9 @@ class System(item.Item):
         # this is by design as inheritable systems don't make sense.
         if self.name is None:
             raise CX(_("need to specify a name for this object"))
-        if self.profile is None and self.image is None:
+        if self.profile in [ None, "" ] and self.image in [ None,"" ]:
             raise CX(_("need to specify a profile or image as a parent for this system"))
-        if self.profile is not None and self.image is not None and self.profile != "" and self.image != "":
-            raise CX(_("image and profile are mutually exclusive (%s,%s)") % (self.profile,self.image))
+
         return True
 
     def set_kickstart(self,kickstart):
