@@ -44,6 +44,7 @@ import item_system
 import item_repo
 import item_image
 from utils import *
+from utils import _
 
 # FIXME: make configurable?
 TOKEN_TIMEOUT = 60*60 # 60 minutes
@@ -185,7 +186,7 @@ class CobblerXMLRPCInterface:
 
     def is_kickstart_in_use(self,ks,token,**rest):
         self.log("is_kickstart_in_use",token=token)
-        self.check_access(token, "is_kickstart_in_use")
+        # do not check access on this method, it's essentially read-only
         for x in self.api.profiles():
            if x.kickstart is not None and x.kickstart == ks:
                return True
@@ -1046,25 +1047,25 @@ class CobblerReadWriteXMLRPCInterface(CobblerXMLRPCInterface):
         obj = self.__get_object(object_id)
         return self.api.copy_distro(obj,newname)
 
-    def copy_profile(self,object_id,token=None):
+    def copy_profile(self,object_id,newname,token=None):
         self.log("copy_profile",object_id=object_id,token=token)
         self.check_access(token,"copy_profile")
         obj = self.__get_object(object_id)
         return self.api.copy_profile(obj,newname)
 
-    def copy_system(self,object_id,token=None):
+    def copy_system(self,object_id,newname,token=None):
         self.log("copy_system",object_id=object_id,token=token)
         self.check_access(token,"copy_system")
         obj = self.__get_object(object_id)
         return self.api.copy_system(obj,newname)
 
-    def copy_repo(self,object_id,token=None):
+    def copy_repo(self,object_id,newname,token=None):
         self.log("copy_repo",object_id=object_id,token=token)
         self.check_access(token,"copy_repo")
         obj = self.__get_object(object_id)
         return self.api.copy_repo(obj,newname)
 
-    def copy_image(self,object_id,token=None):
+    def copy_image(self,object_id,newname,token=None):
         self.log("copy_image",object_id=object_id,token=token)
         self.check_access(token,"copy_image")
         obj = self.__get_object(object_id)
@@ -1174,15 +1175,10 @@ class CobblerReadWriteXMLRPCInterface(CobblerXMLRPCInterface):
         """
         Deletes a profile from a collection.  Note that this just requires the name
         """
-        self.check_access(token, "get_kickstart_templates")
-        files = {} 
-        for x in self.api.profiles():
-           if x.kickstart is not None and x.kickstart != "" and x.kickstart != "<<inherit>>":
-              files[x.kickstart] = 1
-        for x in self.api.systems():
-           if x.kickstart is not None and x.kickstart != "" and x.kickstart != "<<inherit>>":
-              files[x.kickstart] = 1
-        return files.keys() 
+        self.log("remove_profile (%s)" % recursive,name=name,token=token)
+        self.check_access(token, "remove_profile", name)
+        rc = self.api._config.profiles().remove(name,recursive=True)
+        return rc
 
     def remove_system(self,name,token,recursive=1):
         """
